@@ -8,8 +8,10 @@ from collections import OrderedDict
 # We may need below, we may not. What can I say? Dill waters run deep.
 import dill
 
+from pyqalx import QalxBot
 from pyqalx.config import BotConfig, UserConfig
 from pyqalx.core.adapters import QalxQueue, QalxWorker
+from pyqalx.core.enums import ValidStates
 from pyqalx.core.session import QalxSession
 from pyqalx.core.errors import (
     QalxBotInitialisationFailed,
@@ -607,7 +609,7 @@ class Worker(Process):
         queue,
         bot_entity,
         api_entity,
-        worker_adapter,
+        worker_adapter: QalxWorker,
         index,
         workflow,
         **kwargs,
@@ -625,6 +627,7 @@ class Worker(Process):
 
         self.log = None
         self.queue_adapter = QalxQueue(session=self.session)
+        self.bot_adapter = QalxBot(session=self.session)
         self.stop = False
         self.config = self.session.config
         self.index = index
@@ -880,6 +883,16 @@ class Worker(Process):
                 if self._continue_processing():
                     self.job._current_step = step_name
                     try:
+                        # Update bot and worker states here so that the state is correct
+                        # after a `resume` signal is sent
+                        self.worker_adapter.update_state(
+                            self.api_entity,
+                            ValidStates.ACTIVE,
+                            bot_entity=self.bot_entity,
+                        )
+                        self.bot_adapter.update_state(
+                            self.bot_entity, ValidStates.ACTIVE
+                        )
                         fn(self.job)
                     except Exception:
                         # This needs to be a bare exception to handle
@@ -938,6 +951,13 @@ class Worker(Process):
             if self.job.get_entity(entity_type, entity_guid):
                 process_as_far_as_possible(process_functions)
         else:
+            self.worker_adapter.update_state(
+                self.api_entity, ValidStates.IDLE, bot_entity=self.bot_entity
+            )
+            if ValidStates.ACTIVE.value not in [
+                worker.state for worker in self.bot_entity.workers
+            ]:
+                self.bot_adapter.update_state(self.bot_entity, ValidStates.IDLE)
             self._delete_message()
 
     def run(self):
