@@ -221,8 +221,8 @@ class FactoryBuildMixin:
             # Namedspaced metadata to avoid potential name clashing
             # with any custom metadata provided by the user.
             BaseFactory.PYQALX_METADATA_NAMESPACE_KEY: {
-                BaseFactory.PYQALX_METADATA_STAGE_KEY: entity["stage"],
-                BaseFactory.PYQALX_METADATA_FACTORY_GUID_KEY: entity["guid"],
+                BaseFactory.PYQALX_METADATA_STAGE_KEY: entity.stage,
+                BaseFactory.PYQALX_METADATA_FACTORY_GUID_KEY: entity.guid,
             },
         }
         if plan_bot_name is not None:
@@ -287,7 +287,7 @@ class FactoryBuildMixin:
                     # pypi bots won't have a file
                     item["source"] = zip_path
                 item_dict_list.append(item)
-        self.bot_items = self.session.item.add_many(item_dict_list)["items"]
+        self.bot_items = self.session.item.add_many(item_dict_list).items_
 
     @staticmethod
     def _sanitise_cli_key(k):
@@ -409,7 +409,7 @@ class FactoryBuildMixin:
         query = f"metadata.data.{namespace_key}"
         items = self.session.item.find(
             query={
-                f"{query}.{factory_guid_key}": self.entity["guid"],
+                f"{query}.{factory_guid_key}": self.entity.guid,
                 f"{query}.{plan_bot_name_key}": {"$in": bot_names},
             }
         )
@@ -418,14 +418,12 @@ class FactoryBuildMixin:
         # for, download the code and then start the bot (async)
         results = []
         start_context = {}
-        max_workers = items["query"]["count"]
+        max_workers = items.query.count
         with concurrent.futures.ThreadPoolExecutor(
             max_workers=max_workers
         ) as executor:
-            for bot_code_item in items["data"]:
-                bot_name = bot_code_item["meta"][namespace_key][
-                    plan_bot_name_key
-                ]
+            for bot_code_item in items.data:
+                bot_name = bot_code_item.meta[namespace_key][plan_bot_name_key]
                 bot = self._plan_bots[bot_name]
                 bot_source = QalxItemBotSource(
                     bot_name=bot_name,
@@ -631,7 +629,7 @@ class FactoryBuildMixin:
         namespace_key = self.PYQALX_METADATA_NAMESPACE_KEY
         plan_bot_name_key = self.PYQALX_METADATA_PLAN_BOT_NAME_KEY
         item_bot_name_to_guid = {
-            item["meta"][namespace_key][plan_bot_name_key]: item["guid"]
+            item.meta[namespace_key][plan_bot_name_key]: item.guid
             for item in self.bot_items
         }
 
@@ -704,7 +702,7 @@ class FactoryDemolishMixin:
             # on a given bot
             return [
                 self.session.worker.signal_class(_worker).terminate_warm
-                for _worker in _bot["workers"]
+                for _worker in _bot.workers
             ]
 
         terminated_signals = _terminate_warm(bot)
@@ -949,7 +947,7 @@ class BaseFactory(
         :return: The stage for this factory
         """
         if self.entity is not None:
-            self.stage = self.entity["stage"]
+            self.stage = self.entity.stage
         return self.__stage
 
     @stage.setter
@@ -1063,7 +1061,7 @@ class BaseFactory(
             }
             bots = self.session.bot.find(query=query)
 
-            for bot_entity in bots["data"]:
+            for bot_entity in bots.data:
                 plan_bot_name = bot_entity.meta[namespace_key][
                     plan_bot_name_key
                 ]
@@ -1107,7 +1105,7 @@ class BaseFactory(
             f"metadata.data.{namespace_key}.{factory_guid_key}": self.entity.guid
         }
         items = self.session.item.find(query=query)
-        for item in items["data"]:
+        for item in items.data:
             try:
                 self.session.item.delete(item)
             except QalxAPIResponseError as exc:
@@ -1138,13 +1136,13 @@ class BaseFactory(
         remote instance.
         """
         deleted_stacks = []
-        if self.entity["stacks"]:
+        if self.entity.stacks:
             # May not be stacks if there was an error during stack creation
             for provider in self.stacks:
                 if not isinstance(provider, LocalProvider):
                     # LocalProviders won't have a stack to delete.
                     for sector_name in provider.stack.keys():
-                        stack_id = self.entity["stacks"][sector_name]
+                        stack_id = self.entity.stacks[sector_name]
                         if stack_id not in deleted_stacks:
                             # Multiple sectors could share the same stack.
                             # Ensure that we only call delete once per stack
